# -*- coding: utf-8 -*-
# Generated by Django 1.11.29 on 2020-07-15 16:10
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('regex_match', '0006_auto_20160916_1428'),
    ]

    operations = [
        migrations.AlterField(
            model_name='parser',
            name='parser_method_params',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
    ]
